@@ -14,7 +14,7 @@ class Config(BaseSettings):
     title: str = "谁在窥屏"
     content: str = "抓住你了！"
     source: str = "I Got U"
-    image: str = "https://static-cdn.p0ise.cn/2022/11/20221120180503774.jpg"
+    image: str = "random"
 
     class Config:
         extra = "ignore"
